@@ -3,11 +3,7 @@
 #include <Rdefines.h>
 #include <R_ext/Error.h>
 
-#ifdef _WIN32
-    #include "hdf5/hdf5.h"
-#else
-    #include "hdf5/src/hdf5.h"
-#endif
+#include <hdf5.h>
 
 SEXP Rhdf5lib_hdf5_libversion(void)
 {
@@ -50,5 +46,6 @@ R_CallMethodDef callMethods[] = {
 void R_init_Rhdf5lib(DllInfo *info)
 {
   R_registerRoutines(info, NULL, callMethods, NULL, NULL);
+  R_useDynamicSymbols(info, FALSE);
 }
 
